==> kotlin-compiler-0.6.1411-sources.jar: org/jetbrains/jet/j2k/ast/MethodCallExpression.kt <==
/*
 * Copyright 2010-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.j2k.ast

import org.jetbrains.jet.j2k.ast.types.Type

public open class MethodCallExpression(val methodCall: Expression,
                                       val arguments: List<Expression>,
                                       val typeParameters: List<Type>,
                                       val resultIsNullable: Boolean = false) : Expression() {
    public override fun isNullable(): Boolean = methodCall.isNullable() || resultIsNullable

    public override fun toKotlin(): String {
        val typeParamsToKotlin: String = typeParameters.toKotlin(", ", "<", ">")
        val argumentsMapped = arguments.map { it.toKotlin() }
        return methodCall.toKotlin() + typeParamsToKotlin + "(" + argumentsMapped.makeString(", ") + ")"
    }

    class object {
        fun build(receiver: Expression, methodName: String, arguments: List<Expression> = arrayList()): MethodCallExpression {
            return MethodCallExpression(CallChainExpression(receiver, Identifier(methodName, false)),
                                        arguments,
                                        arrayList(), false)
        }
    }
}

==> kotlin-compiler-0.7.5-sources.jar: org/jetbrains/jet/j2k/ast/MethodCallExpression.kt <==
/*
 * Copyright 2010-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.jet.j2k.ast

import org.jetbrains.jet.j2k.ast.types.Type
import java.util.ArrayList

open class MethodCallExpression(
        val methodCall: Expression,
        val arguments: List<Expression>,
        val typeParameters: List<Type>,
        val resultIsNullable: Boolean = false
) : Expression() {
    override fun isNullable(): Boolean = methodCall.isNullable() || resultIsNullable

    override fun toKotlin(): String {
        val typeParamsToKotlin: String = typeParameters.toKotlin(", ", "<", ">")
        val argumentsMapped = arguments.map { it.toKotlin() }
        return methodCall.toKotlin() + typeParamsToKotlin + "(" + argumentsMapped.makeString(", ") + ")"
    }

    class object {
        fun build(receiver: Expression, methodName: String, arguments: List<Expression> = ArrayList()): MethodCallExpression {
            return MethodCallExpression(CallChainExpression(receiver, Identifier(methodName, false)),
                                        arguments,
                                        ArrayList(), false)
        }
    }
}
